import unittest
import pandas as pd

from lhcsmapi.analysis.RQCircuitAnalysis import RQCircuitAnalysis
from lhcsmapi.analysis.RQCircuitQuery import RQCircuitQuery


class RQCircuitAnalysisTest(unittest.TestCase):
    def test_create_timestamp_report(self):
        # arrange
        timestamp_pic_rqd = 1544622149611000000
        timestamp_pic_rqf = 1544622149611000000
        timestamp_fgc_rqd = 1544622149620000000
        timestamp_fgc_rqf = 1544622149620000000

        source_timestamp_qds_rqd_df = pd.DataFrame({'source': {0: '16L2'}, 'timestamp': {0: 1544622149598000000}})
        source_timestamp_nqps_rqd_df = pd.DataFrame({'source': {0: 'B17L2'}, 'timestamp': {0: 1544622149613000000}})
        source_timestamp_ee_rqd_df = pd.DataFrame(
            {'source': {0: 'UA23.RQD.A12'}, 'timestamp': {0: 1544622149701000000}})
        source_timestamp_ee_rqf_df = pd.DataFrame(
            {'source': {0: 'UA23.RQF.A12'}, 'timestamp': {0: 1544622149701000000}})
        source_timestamp_leads_rqd_df = pd.DataFrame()
        source_timestamp_leads_rqf_df = pd.DataFrame()

        circuit_type = 'RQ'

        # act
        timestamp_report_act = RQCircuitAnalysis(circuit_type).create_timestamp_report(timestamp_pic_rqd,
                                                                                       timestamp_pic_rqf,
                                                                                       timestamp_fgc_rqd,
                                                                                       timestamp_fgc_rqf,
                                                                                       source_timestamp_qds_rqd_df,
                                                                                       source_timestamp_nqps_rqd_df,
                                                                                       source_timestamp_ee_rqd_df,
                                                                                       source_timestamp_ee_rqf_df,
                                                                                       source_timestamp_leads_rqd_df,
                                                                                       source_timestamp_leads_rqf_df)

        timestamp_report_ref = pd.DataFrame({'Source': {0: 'iQPS',
                                                        1: 'PIC_RQD',
                                                        2: 'PIC_RQF',
                                                        3: 'nQPS',
                                                        4: 'FGC_RQD',
                                                        5: 'FGC_RQF',
                                                        6: 'EE_RQD',
                                                        7: 'EE_RQF'},
                                             'Timestamp': {0: 1544622149598000000,
                                                           1: 1544622149611000000,
                                                           2: 1544622149611000000,
                                                           3: 1544622149613000000,
                                                           4: 1544622149620000000,
                                                           5: 1544622149620000000,
                                                           6: 1544622149701000000,
                                                           7: 1544622149701000000},
                                             'Date and time': {0: '2018-12-12 14:42:29.598',
                                                               1: '2018-12-12 14:42:29.611',
                                                               2: '2018-12-12 14:42:29.611',
                                                               3: '2018-12-12 14:42:29.613',
                                                               4: '2018-12-12 14:42:29.620',
                                                               5: '2018-12-12 14:42:29.620',
                                                               6: '2018-12-12 14:42:29.701',
                                                               7: '2018-12-12 14:42:29.701'}})

        # assert
        pd.testing.assert_frame_equal(timestamp_report_ref, timestamp_report_act)


    def test_collecting_data(self):
        # arrange
        author = 'hagen'
        circuit_type = 'RQ'
        circuit_names = ('RQD.A81', 'RQF.A81')
        timestamp_fgc_rqd, timestamp_fgc_rqf = (1543859470880000000, 1543859470880000000)
        is_automatic = True

        return

        # act
        rqd_query = RQCircuitQuery(circuit_type, circuit_names[0])
        rqf_query = RQCircuitQuery(circuit_type, circuit_names[1])

        # PC
        i_meas_rqd_df, i_a_rqd_df, i_earth_rqd_df, i_earth_pcnt_rqd_df, i_ref_rqd_df = rqd_query.query_pc_pm(
            timestamp_fgc_rqd, timestamp_fgc_rqd,
            signal_names=['I_MEAS', 'I_A', 'I_EARTH', 'I_EARTH_PCNT', 'I_REF'])

        i_meas_rqf_df, i_a_rqf_df, i_earth_rqf_df, i_earth_pcnt_rqf_df, i_ref_rqf_df = rqf_query.query_pc_pm(
            timestamp_fgc_rqf, timestamp_fgc_rqf,
            signal_names=['I_MEAS', 'I_A', 'I_EARTH', 'I_EARTH_PCNT', 'I_REF'])

        timestamp_fgc_ref_rqd = rqd_query.get_timestamp_ref(col='fgcPm')
        timestamp_fgc_ref_rqf = rqf_query.get_timestamp_ref(col='fgcPm')

        i_meas_ref_rqd_df, i_earth_rqd_ref_df, i_earth_pcnt_rqd_ref_df = rqd_query.query_pc_pm(
            timestamp_fgc_ref_rqd, timestamp_fgc_ref_rqd,
            signal_names=['I_MEAS', 'I_EARTH', 'I_EARTH_PCNT'])

        i_meas_ref_rqf_df, i_earth_rqf_ref_df, i_earth_pcnt_rqf_ref_df = rqf_query.query_pc_pm(
            timestamp_fgc_ref_rqf, timestamp_fgc_ref_rqf,
            signal_names=['I_MEAS', 'I_EARTH', 'I_EARTH_PCNT'])

        # PIC
        # timestamp_pic_rqd = rqd_query.find_timestamp_pic(timestamp_fgc_rqd, spark=spark)
        # timestamp_pic_rqf = rqf_query.find_timestamp_pic(timestamp_fgc_rqf, spark=spark)

        # EE
        source_timestamp_ee_rqd_df = rqd_query.find_source_timestamp_ee(timestamp_fgc_rqd)
        timestamp_ee_rqd = source_timestamp_ee_rqd_df.loc[0, 'timestamp']
        u_dump_res_rqd_df = \
            rqd_query.query_ee_u_dump_res_pm(timestamp_ee_rqd, timestamp_fgc_rqd, signal_names=['U_DUMP_RES'])[0]

        source_timestamp_ee_rqf_df = rqf_query.find_source_timestamp_ee(timestamp_fgc_rqf)
        timestamp_ee_rqf = source_timestamp_ee_rqf_df.loc[0, 'timestamp']
        u_dump_res_rqf_df = \
            rqf_query.query_ee_u_dump_res_pm(timestamp_ee_rqf, timestamp_fgc_rqf, signal_names=['U_DUMP_RES'])[0]

        t_res_0_rqd_df = \
            rqd_query.query_ee_t_res_pm(source_timestamp_ee_rqd_df.loc[0, 'timestamp'], timestamp_fgc_rqd,
                                        signal_names=['T_RES'])[0]
        t_res_1_rqd_df = \
            rqd_query.query_ee_t_res_pm(source_timestamp_ee_rqd_df.loc[1, 'timestamp'], timestamp_fgc_rqd,
                                        signal_names=['T_RES'])[0]

        t_res_0_rqf_df = \
            rqf_query.query_ee_t_res_pm(source_timestamp_ee_rqf_df.loc[0, 'timestamp'], timestamp_fgc_rqf,
                                        signal_names=['T_RES'])[0]
        t_res_1_rqf_df = \
            rqf_query.query_ee_t_res_pm(source_timestamp_ee_rqf_df.loc[1, 'timestamp'], timestamp_fgc_rqf,
                                        signal_names=['T_RES'])[0]

        # EE - REF
        timestamp_ee_ref_rqd = rqd_query.get_timestamp_ref(col='eePm')
        timestamp_ee_ref_rqf = rqf_query.get_timestamp_ref(col='eePm')

        source_timestamp_ee_rqd_ref_df = rqd_query.find_source_timestamp_ee(timestamp_ee_ref_rqd)
        source_timestamp_ee_rqf_ref_df = rqf_query.find_source_timestamp_ee(timestamp_ee_ref_rqf)

        t_res_0_rqd_ref_df = \
            rqd_query.query_ee_t_res_pm(source_timestamp_ee_rqd_ref_df.loc[0, 'timestamp'], timestamp_fgc_ref_rqd,
                                        signal_names=['T_RES'])[0]
        t_res_1_rqd_ref_df = \
            rqd_query.query_ee_t_res_pm(source_timestamp_ee_rqd_ref_df.loc[1, 'timestamp'], timestamp_fgc_ref_rqd,
                                        signal_names=['T_RES'])[0]

        t_res_0_rqf_ref_df = \
            rqf_query.query_ee_t_res_pm(source_timestamp_ee_rqf_ref_df.loc[0, 'timestamp'], timestamp_fgc_ref_rqf,
                                        signal_names=['T_RES'])[0]
        t_res_1_rqf_ref_df = \
            rqf_query.query_ee_t_res_pm(source_timestamp_ee_rqf_ref_df.loc[1, 'timestamp'], timestamp_fgc_ref_rqf,
                                        signal_names=['T_RES'])[0]

        # iQPS
        source_timestamp_qds_rq_df = rqd_query.find_source_timestamp_qds(timestamp_fgc_rqd)

        report_analysis = rqd_query.create_report_analysis_template(source_timestamp_qds_rq_df, timestamp_fgc_rqd,
                                                                    i_meas_rqd_df, i_meas_rqf_df, author)

        iqps_analog_dfs = rqd_query.query_iqps_analog_pm(source_timestamp_qds_rq_df,
                                                         signals=['U_QS0_EXT', 'U_QS0_INT', 'U_1_EXT', 'U_2_EXT',
                                                                  'U_1_INT', 'U_2_INT'])
        iqps_digital_dfs = rqd_query.query_iqps_analog_pm(source_timestamp_qds_rq_df,
                                                          signals=['ST_MAGNET_OK_EXT', 'ST_MAGNET_OK_INT',
                                                                   'ST_NQD0_EXT', 'ST_NQD0_INT'])

        # nQPS
        source_timestamp_nqps_rqd_df = rqd_query.find_source_timestamp_nqps(timestamp_fgc_rqd)
        source_timestamp_nqps_rqf_df = rqd_query.find_source_timestamp_nqps(timestamp_fgc_rqd)
        u_nqps_rqd_dfs = rqd_query.query_nqps_voltage_pm(source_timestamp_qds_rq_df)
        u_nqps_rqf_dfs = rqf_query.query_nqps_voltage_pm(source_timestamp_qds_rq_df)

        # QH
        u_hds_rq_dfs = rqd_query.query_voltage_qh_pm(source_timestamp_qds_rq_df)
        u_hds_rq_ref_dfs = rqd_query.query_voltage_qh_ref_pm(source_timestamp_qds_rq_df)

        # DIODE LEADS
        i_meas_u_diode_u_ref_rqd_pm_dfs = rqd_query.query_current_voltage_diode_leads_pm(timestamp_fgc_rqd,
                                                                                         source_timestamp_qds_rq_df)
        # i_meas_u_diode_rqd_nxcals_dfs = rqd_query.query_current_voltage_diode_leads_nxcals(
        #    source_timestamp_qds_rq_df, spark=spark)

        i_meas_u_diode_u_ref_rqf_pm_dfs = rqf_query.query_current_voltage_diode_leads_pm(timestamp_fgc_rqf,
                                                                                         source_timestamp_qds_rq_df)
        # i_meas_u_diode_rqf_nxcals_dfs = rqf_query.query_current_voltage_diode_leads_nxcals(
        #    source_timestamp_qds_rq_df, spark=spark)

        # DFB
        # source_timestamp_leads_rqd_df = rqd_query.find_timestamp_leads(timestamp_fgc_rqd)
        # u_hts_rqd_dfs = rqd_query.query_leads_res_hts_voltage(timestamp_fgc_rqd, source_timestamp_leads_rqd_df,
        #                                                      signal_names=['U_HTS'], spark=spark)
        # u_res_rqd_dfs = rqd_query.query_leads_res_hts_voltage(timestamp_fgc_rqd, source_timestamp_leads_rqd_df,
        #                                                      signal_names=['U_RES'], spark=spark)

        # source_timestamp_leads_rqf_df = rqf_query.find_timestamp_leads(timestamp_fgc_rqf)
        # u_hts_rqf_dfs = rqf_query.query_leads_res_hts_voltage(timestamp_fgc_rqf, source_timestamp_leads_rqf_df,
        #                                                      signal_names=['U_HTS'], spark=spark)
        # u_res_rqf_dfs = rqf_query.query_leads_res_hts_voltage(timestamp_fgc_rqf, source_timestamp_leads_rqf_df,
        #                                                      signal_names=['U_RES'], spark=spark)

        # U_DIODE
        # u_diode_rqd_dfs = rqd_query.query_u_diode_cals(timestamp_fgc_rqd, ldb=ldb)
        # u_diode_rqf_dfs = rqf_query.query_u_diode_cals(timestamp_fgc_rqf, ldb=ldb)

        # U_EARTH
        # u_earth_rqd_dfs = rqd_query.query_u_earth_cals(timestamp_fgc_rqd, ldb=ldb)
        # u_earth_rqf_dfs = rqf_query.query_u_earth_cals(timestamp_fgc_rqf, ldb=ldb)

        # assert
        self.assertEqual(True, True)
